# frozen_string_literal: true

require 'uri'
require_relative 'client'

class DistributedPress
  module V1
    module Social
      # Manages the actor's inbox on the Social Inbox
      class Inbox
        # @return [DistributedPress::V1::Social::Client]
        attr_reader :client

        # @return [String]
        attr_reader :actor

        # @param :client [DistributedPress::V1::Social::Client]
        # @param :actor [String]
        def initialize(client:, actor:)
          @client = client
          @actor = actor
        end

        # Get the actor's inbox
        #
        # @return [HTTParty::Response]
        def get
          client.get(endpoint: endpoint)
        end

        # Send an activity to the actor's inbox. This is typically done
        # by other actors though, not ourselves, so it could be used to
        # send directly to another Actor's Social Inbox.
        #
        # @param :activity [Hash]
        # @return [HTTParty::Response]
        def post(activity:)
          client.post(endpoint: endpoint, body: activity)
        end

        # Reject an activity queued on the inbox
        #
        # @param :id [String] Activity ID
        # @return [HTTParty::Response]
        def reject(id:)
          client.delete(endpoint: "#{endpoint}/#{URI.encode_uri_component(id)}")
        end

        # Accept an activity queued on the inbox
        #
        # @param :id [String] Activity ID
        # @return [HTTParty::Response]
        def accept(id:)
          client.post(endpoint: "#{endpoint}/#{URI.encode_uri_component(id)}", body: nil)
        end

        # Inbox
        #
        # @return [String]
        def endpoint
          @endpoint ||= "/v1/#{actor}/inbox"
        end
      end
    end
  end
end
